@@ -72,16 +72,14 @@ enum
 /* static guint champlain_map_source_factory_signals[LAST_SIGNAL] = { 0, }; */
 static ChamplainMapSourceFactory *instance = NULL;
 
-G_DEFINE_TYPE (ChamplainMapSourceFactory, champlain_map_source_factory, G_TYPE_OBJECT);
-
-#define GET_PRIVATE(obj) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, ChamplainMapSourceFactoryPrivate))
-
 struct _ChamplainMapSourceFactoryPrivate
 {
   GSList *registered_sources;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (ChamplainMapSourceFactory, champlain_map_source_factory, G_TYPE_OBJECT)
+
+
 static ChamplainMapSource *champlain_map_source_new_generic (
     ChamplainMapSourceDesc *desc);
 
@@ -119,7 +117,7 @@ champlain_map_source_factory_constructor (GType type,
     }
   else
     {
-      retval = g_object_ref (instance);
+      retval = G_OBJECT( g_object_ref (instance));
     }
 
   return retval;
@@ -129,8 +127,6 @@ champlain_map_source_factory_constructor (GType type,
 static void
 champlain_map_source_factory_class_init (ChamplainMapSourceFactoryClass *klass)
 {
-  g_type_class_add_private (klass, sizeof (ChamplainMapSourceFactoryPrivate));
-
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->constructor = champlain_map_source_factory_constructor;
@@ -141,7 +137,7 @@ champlain_map_source_factory_class_init (ChamplainMapSourceFactoryClass *klass)
 static void
 champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
 {
-  ChamplainMapSourceFactoryPrivate *priv = GET_PRIVATE (factory);
+  ChamplainMapSourceFactoryPrivate *priv = champlain_map_source_factory_get_instance_private (factory);
   ChamplainMapSourceDesc *desc;
 
   factory->priv = priv;
@@ -151,7 +147,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OSM_MAPNIK,
         "OpenStreetMap Mapnik",
         "Map Data ODBL OpenStreetMap Contributors, Map Imagery CC-BY-SA 2.0 OpenStreetMap",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         18,
         256,
@@ -165,7 +161,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OSM_CYCLE_MAP,
         "OpenStreetMap Cycle Map",
         "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         18,
         256,
@@ -179,7 +175,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OSM_TRANSPORT_MAP,
         "OpenStreetMap Transport Map",
         "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         18,
         256,
@@ -193,12 +189,12 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_MFF_RELIEF,
         "Maps for Free Relief",
         "Map data available under GNU Free Documentation license, Version 1.2 or later",
-        "http://www.gnu.org/copyleft/fdl.html",
+        "https://www.gnu.org/copyleft/fdl.html",
         0,
         11,
         256,
         CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-        "http://maps-for-free.com/layer/relief/z#Z#/row#Y#/#Z#_#X#-#Y#.jpg",
+        "https://maps-for-free.com/layer/relief/z#Z#/row#Y#/#Z#_#X#-#Y#.jpg",
         champlain_map_source_new_generic,
         NULL);
   champlain_map_source_factory_register (factory, desc);
@@ -207,12 +203,12 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OWM_CLOUDS,
         "OpenWeatherMap cloud layer",
         "Map data is CC-BY-SA 2.0 OpenWeatherMap contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         18,
         256,
         CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-        "http://tile.openweathermap.org/map/clouds/#Z#/#X#/#Y#.png",
+        "https://tile.openweathermap.org/map/clouds/#Z#/#X#/#Y#.png",
         champlain_map_source_new_generic,
         NULL);
   champlain_map_source_factory_register (factory, desc);
@@ -221,12 +217,12 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OWM_WIND,
         "OpenWeatherMap wind layer",
         "Map data is CC-BY-SA 2.0 OpenWeatherMap contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         18,
         256,
         CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-        "http://tile.openweathermap.org/map/wind/#Z#/#X#/#Y#.png",
+        "https://tile.openweathermap.org/map/wind/#Z#/#X#/#Y#.png",
         champlain_map_source_new_generic,
         NULL);
   champlain_map_source_factory_register (factory, desc);
@@ -235,12 +231,12 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OWM_TEMPERATURE,
         "OpenWeatherMap temperature layer",
         "Map data is CC-BY-SA 2.0 OpenWeatherMap contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         18,
         256,
         CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-        "http://tile.openweathermap.org/map/temp/#Z#/#X#/#Y#.png",
+        "https://tile.openweathermap.org/map/temp/#Z#/#X#/#Y#.png",
         champlain_map_source_new_generic,
         NULL);
   champlain_map_source_factory_register (factory, desc);
@@ -249,12 +245,12 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OWM_PRECIPITATION,
         "OpenWeatherMap precipitation layer",
         "Map data is CC-BY-SA 2.0 OpenWeatherMap contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         18,
         256,
         CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-        "http://tile.openweathermap.org/map/precipitation/#Z#/#X#/#Y#.png",
+        "https://tile.openweathermap.org/map/precipitation/#Z#/#X#/#Y#.png",
         champlain_map_source_new_generic,
         NULL);
   champlain_map_source_factory_register (factory, desc);
@@ -263,12 +259,12 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OWM_PRESSURE,
         "OpenWeatherMap sea level pressure layer",
         "Map data is CC-BY-SA 2.0 OpenWeatherMap contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         18,
         256,
         CHAMPLAIN_MAP_PROJECTION_MERCATOR,
-        "http://tile.openweathermap.org/map/pressure/#Z#/#X#/#Y#.png",
+        "https://tile.openweathermap.org/map/pressure/#Z#/#X#/#Y#.png",
         champlain_map_source_new_generic,
         NULL);
   champlain_map_source_factory_register (factory, desc);
@@ -278,7 +274,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_MEMPHIS_LOCAL,
         "OpenStreetMap Memphis Local Map",
         "(CC) BY 2.0 OpenStreetMap contributors",
-        "http://creativecommons.org/licenses/by/2.0/",
+        "https://creativecommons.org/licenses/by/2.0/",
         12,
         18,
         256,
@@ -292,7 +288,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_MEMPHIS_NETWORK,
         "OpenStreetMap Memphis Network Map",
         "(CC) BY 2.0 OpenStreetMap contributors",
-        "http://creativecommons.org/licenses/by/2.0/",
+        "https://creativecommons.org/licenses/by/2.0/",
         12,
         18,
         256,
@@ -309,7 +305,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OSM_AERIAL_MAP,
         "MapQuest Open Aerial",
         "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         18,
         256,
@@ -323,7 +319,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OSM_MAPQUEST,
         "MapQuest OSM",
         "Data, imagery and map information provided by MapQuest, Open Street Map and contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         17,
         256,
@@ -337,7 +333,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OAM,
         "OpenAerialMap",
         "(CC) BY 3.0 OpenAerialMap contributors",
-        "http://creativecommons.org/licenses/by/3.0/",
+        "https://creativecommons.org/licenses/by/3.0/",
         0,
         17,
         256,
@@ -351,7 +347,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
         CHAMPLAIN_MAP_SOURCE_OSM_OSMARENDER,
         "OpenStreetMap Osmarender",
         "Map data is CC-BY-SA 2.0 OpenStreetMap contributors",
-        "http://creativecommons.org/licenses/by-sa/2.0/",
+        "https://creativecommons.org/licenses/by-sa/2.0/",
         0,
         17,
         256,
