@@ -62,19 +62,10 @@ enum
   PROP_URI_FORMAT,
   PROP_OFFLINE,
   PROP_PROXY_URI,
-  PROP_MAX_CONNS
+  PROP_MAX_CONNS,
+  PROP_USER_AGENT
 };
 
-G_DEFINE_TYPE (ChamplainNetworkTileSource, champlain_network_tile_source, CHAMPLAIN_TYPE_TILE_SOURCE);
-
-#define GET_PRIVATE(obj) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CHAMPLAIN_TYPE_NETWORK_TILE_SOURCE, ChamplainNetworkTileSourcePrivate))
-
-/* The osm.org tile set require us to use no more than 2 simultaneous
- * connections so let that be the default.
- */
-#define MAX_CONNS_DEFAULT 2
-
 struct _ChamplainNetworkTileSourcePrivate
 {
   gboolean offline;
@@ -84,6 +75,13 @@ struct _ChamplainNetworkTileSourcePrivate
   gint max_conns;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (ChamplainNetworkTileSource, champlain_network_tile_source, CHAMPLAIN_TYPE_TILE_SOURCE)
+
+/* The osm.org tile set require us to use no more than 2 simultaneous
+ * connections so let that be the default.
+ */
+#define MAX_CONNS_DEFAULT 2
+
 typedef struct
 {
   ChamplainMapSource *map_source;
@@ -173,6 +171,10 @@ champlain_network_tile_source_set_property (GObject *object,
       champlain_network_tile_source_set_max_conns (tile_source, g_value_get_int (value));
       break;
 
+    case PROP_USER_AGENT:
+      champlain_network_tile_source_set_user_agent (tile_source, g_value_get_string (value));
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -221,8 +223,6 @@ champlain_network_tile_source_class_init (ChamplainNetworkTileSourceClass *klass
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GParamSpec *pspec;
 
-  g_type_class_add_private (klass, sizeof (ChamplainNetworkTileSourcePrivate));
-
   object_class->finalize = champlain_network_tile_source_finalize;
   object_class->dispose = champlain_network_tile_source_dispose;
   object_class->get_property = champlain_network_tile_source_get_property;
@@ -295,13 +295,27 @@ champlain_network_tile_source_class_init (ChamplainNetworkTileSourceClass *klass
 
   g_object_class_install_property (object_class, PROP_MAX_CONNS, pspec);
 
+  /**
+   * ChamplainNetworkTileSource:user-agent:
+   *
+   * The HTTP user agent used for requests
+   *
+   * Since: 0.12.16
+   */
+  pspec = g_param_spec_string ("user-agent",
+        "HTTP User Agent",
+        "The HTTP user agent used for network requests",
+        "libchamplain/" CHAMPLAIN_VERSION_S,
+        G_PARAM_WRITABLE);
+
+  g_object_class_install_property (object_class, PROP_USER_AGENT, pspec);
 }
 
 
 static void
 champlain_network_tile_source_init (ChamplainNetworkTileSource *tile_source)
 {
-  ChamplainNetworkTileSourcePrivate *priv = GET_PRIVATE (tile_source);
+  ChamplainNetworkTileSourcePrivate *priv = champlain_network_tile_source_get_instance_private (tile_source);
 
   tile_source->priv = priv;
 
@@ -408,7 +422,7 @@ champlain_network_tile_source_get_uri_format (ChamplainNetworkTileSource *tile_s
  * Y in TMS coordinates.
  *
  * For example, this is the OpenStreetMap URI format:
- * "http://tile.openstreetmap.org/\#Z\#/\#X\#/\#Y\#.png"
+ * "https://tile.openstreetmap.org/\#Z\#/\#X\#/\#Y\#.png"
  *
  * Since: 0.4
  */
@@ -572,6 +586,29 @@ champlain_network_tile_source_set_max_conns (ChamplainNetworkTileSource *tile_so
   g_object_notify (G_OBJECT (tile_source), "max_conns");
 }
 
+/**
+ * champlain_network_tile_source_set_user_agent:
+ * @tile_source: a #ChamplainNetworkTileSource
+ * @user_agent: A User-Agent string
+ *
+ * Sets the User-Agent header used communicating with the server.
+ * Since: 0.12.16
+ */
+void
+champlain_network_tile_source_set_user_agent (
+    ChamplainNetworkTileSource *tile_source,
+    const gchar *user_agent)
+{
+  g_return_if_fail (CHAMPLAIN_IS_NETWORK_TILE_SOURCE (tile_source)
+      && user_agent != NULL);
+
+  ChamplainNetworkTileSourcePrivate *priv = tile_source->priv;
+
+  if (priv->soup_session)
+    g_object_set (G_OBJECT (priv->soup_session), "user-agent",
+        user_agent, NULL);
+}
+
 
 #define SIZE 8
 static gchar *
@@ -723,7 +760,7 @@ tile_loaded_cb (G_GNUC_UNUSED SoupSession *session,
 
   g_signal_connect (tile, "render-complete", G_CALLBACK (tile_rendered_cb), data);
 
-  champlain_renderer_set_data (renderer, msg->response_body->data, msg->response_body->length);
+  champlain_renderer_set_data (renderer, (guint8*) msg->response_body->data, msg->response_body->length);
   champlain_renderer_render (renderer, tile);
 
   return;
